@@ -1,7 +1,7 @@
 package Alien::TinyCC;
 
 # Follow Golden's Version Rule: http://www.dagolden.com/index.php/369/version-numbers-should-be-boring/
-our $VERSION = "0.01";
+our $VERSION = "0.02";
 $VERSION = eval $VERSION;
 
 use File::ShareDir;
@@ -19,7 +19,7 @@ use Carp;
 my $dist_dir;
 
 my $mod_path = $INC{'Alien/TinyCC.pm'};
-if ($mod_path =~ s/(.*)blib.*/${1}share/) {
+if ($mod_path =~ s/(.*)blib.*/$1share/) {
 	$dist_dir = $mod_path;
 	croak('Looks like Alien::TinyCC is being invoked from blib, but I cannot find build-time sharedir!')
 		unless -d $dist_dir;
